#!/usr/bin/python

import sys, os
import shutil, errno
from Bio import SwissProt


#parse UniProtKB file: uniprot_sprot.dat.gz

if len(sys.argv) < 3:
    sys.exit("usage: ./parseUniprot <database_file> <output_file>")

try:
	uniprot = open(sys.argv[1])
except IOError:
	print "Could not find UniProt database in file: ", sys.argv[1]
	exit(-1)

output_file = open(sys.argv[2],"w")
output_file.write("##GENE SYMBOL	UID	GO	pdbs" + "\n")

for record in SwissProt.parse(uniprot):
	#consider only HUMAN
	if "9606" in record.taxonomy_id:
		pdbs = []
		pdb_info = ""
		#get uniprot id
		uid = record.accessions[0]
		
		snp = "-"
		gene_symbol = ""
		gname = record.gene_name.split(";")[0].split("=")
		#get gene symbol/name
		if gname[0] == 'Name':
			gene_symbol = gname[1]

		#get GO info
		cross_refs_GO = [tup for tup in record.cross_references if any(i in tup for i in ["GO"])]
		go = []
		for i in cross_refs_GO:
			go.append(i[2].split(":")[1])

		#get information about available 3D structures
		cross_refs_pdb = [tup for tup in record.cross_references if any(i in tup for i in ["PDB"])]
		for ref in cross_refs_pdb:
			pdbs.append(" ".join(ref[1:]))
		pdb_info = ";".join(pdbs)
		
		
							
		output_file.write(gene_symbol + "\t" + uid + "\t" + ";".join(go) + "\t" + pdb_info + "\n")
		
uniprot.close()
output_file.close()




